"""
Create plots of chess games using .pgn files.

Classes:

    ChessPlot
"""

from .chessplot import ChessPlot
